Configuration Generation Tool

==========================
Mandatory Required modules
==========================
pandas, nettoolkit



update below variable in confGen.py if column names are different in database (excel)
VAR_DB_FIND_COLUMN = 'FIND'
VAR_DB_REPL_COLUMN = 'REPLACE'

update below variable in confGen.py if section identifiers are different in template
SECTION_STARTER = ("GOAHEAD FOR", "REPEAT EACH")
SECTION_STOPPER = ("GOAHEAD END", "REPEAT STOP")

